package com.ylx.massage.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * <p>
 * 提现表
 * </p>
 *
 * @author YJR
 * @since 2023-12-31
 */
@Getter
@Setter
@Accessors(chain = true)
@TableName("t_tx_record")
@ApiModel(value = "TTxRecord", description = "提现表")
public class TTxRecord implements Serializable {

    private static final long serialVersionUID = 1L;

    @TableId("c_id")
    @ApiModelProperty("cId")
    private String cId;

    /**
     * 提现单号
     */
    @TableField("cash_no")
    @ApiModelProperty("提现单号")
    private String cashNo;

    /**
     * 提现用户
     */
    @TableField("c_open_id")
    @ApiModelProperty("提现用户")
    private String cOpenId;


    @TableField("dept_id")
    @ApiModelProperty("部门id")
    private String deptId;

    @TableField("dept_name")
    @ApiModelProperty("部门名称")
    private String deptName;

    /**
     * 提现金额
     */
    @TableField("d_price")
    @ApiModelProperty("提现金额")
    private BigDecimal dPrice;

    /**
     * 提现时间
     */
    @TableField("c_time")
    @ApiModelProperty("提现时间")
    private String cTime;

    /**
     * 手机号
     */
    @TableField("c_phone")
    @ApiModelProperty("手机号")
    private String cPhone;

    /**
     * 姓名
     */
    @TableField("c_name")
    @ApiModelProperty("姓名")
    private String cName;

    /**
     * 开户行
     */
    @TableField("opening_bank")
    @ApiModelProperty("开户行")
    private String openingBank;

    /**
     * 银行账号
     */
    @TableField("bank_account")
    @ApiModelProperty("银行账号")
    private String bankAccount;


    /**
     * 提现图片
     */
    @TableField("c_image")
    @ApiModelProperty("提现图片")
    private String cImage;

    /**
     * 审核中0 审核通过1
     */
    @TableField("n_status")
    @ApiModelProperty("审核中0, 审核通过1, 驳回2")
    private Integer nStatus;

    /**
     * 创建时间
     */
    @TableField("dt_create_time")
    @ApiModelProperty("创建时间")
    private LocalDateTime dtCreateTime;

    @ApiModelProperty("是否删除0否1是")
    @TableLogic
    private Integer isDelete;

    public String getcId() {
        return cId;
    }

    public void setcId(String cId) {
        this.cId = cId;
    }

    public String getcOpenId() {
        return cOpenId;
    }

    public void setcOpenId(String cOpenId) {
        this.cOpenId = cOpenId;
    }

    public BigDecimal getdPrice() {
        return dPrice;
    }

    public void setdPrice(BigDecimal dPrice) {
        this.dPrice = dPrice;
    }

    public String getcTime() {
        return cTime;
    }

    public void setcTime(String cTime) {
        this.cTime = cTime;
    }

    public String getcPhone() {
        return cPhone;
    }

    public void setcPhone(String cPhone) {
        this.cPhone = cPhone;
    }

    public String getcName() {
        return cName;
    }

    public void setcName(String cName) {
        this.cName = cName;
    }

    public String getcImage() {
        return cImage;
    }

    public void setcImage(String cImage) {
        this.cImage = cImage;
    }

    public Integer getnStatus() {
        return nStatus;
    }

    public void setnStatus(Integer nStatus) {
        this.nStatus = nStatus;
    }

    public LocalDateTime getDtCreateTime() {
        return dtCreateTime;
    }

    public void setDtCreateTime(LocalDateTime dtCreateTime) {
        this.dtCreateTime = dtCreateTime;
    }
}
